Sortable – Sorting tables since 2007
Description: Sortable is a Javascript and CSS library for making native HTML tables sortable. It is free and open source and was developed by HubSpot developers Adam Schwartz (@adamfschwartz) and Zack Bloom (@zackbloom).

# Sortable ## Drop-in script to make your tables sortable. ★ On Github Download
Browser | Usage | Initial release | Stable version
--- | --- | --- | ---
Chrome | 42.68% | September 2, 2008 | 31.0.1650.57
Internet Explorer | 25.44% | August 16, 1995 | 11.0.1
Firefox | 20.01% | September 23, 2002 | 25.0.1
Safari | 8.39% | January 7, 2003 | 7.0
Opera | 1.03% | Late 1994 | 18.0.1284.49
Other | 2.44% |  |
Data compiled 11/26/13 from StatCounter and Wikipedia.

# About Sortable is an open-source javascript and CSS library which adds sorting functionality to tables. It is tiny (`<2kb`) and has no dependencies. To use, first download the latest release. Then simply add `sortable.min.js` and a theme file to your page:
    <link rel="stylesheet" href="sortable-theme-dark.css" />
    <script src="sortable.min.js"></script>
Add the attribute `data-sortable` and the theme class name to your `<table>` elements:
    <table class="sortable-theme-dark" data-sortable>
        <!-- ... -->
    </table>
And that's it! Learn more by visiting the documentation.

# Install The easiest way to add Sortable onto your site is with Eager. Click Install to see a live preview of sorted tables on your website.

# Themes ## Sortables for every occasion.
Browser | Usage | Initial release | Stable version
--- | --- | --- | ---
Chrome | 42.68% | September 2, 2008 | 31.0.1650.57
Internet Explorer | 25.44% | August 16, 1995 | 11.0.1
Firefox | 20.01% | September 23, 2002 | 25.0.1
Safari | 8.39% | January 7, 2003 | 7.0
Opera | 1.03% | Late 1994 | 18.0.1284.49
Other | 2.44% |  |
Minimal Light Dark Bootstrap Slick Finder

# Share ## Help us spread the word. Tweet